AdkAbortSignal class

Read-only cancellation signal propagated through an invocation.

Properties

aborted bool
Whether cancellation has been requested.
no setter
hashCode int
The hash code for this object.
no setterinherited
reason Object?
Optional cancellation reason.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener(Object? reason)) → void
Registers listener to run when the signal is aborted.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(void listener(Object? reason)) → void
Removes a previously registered listener.
throwIfAborted() → void
Throws AdkAbortException when aborted is true.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited