BaseTelemetryService class abstract

Contract for telemetry trace/span lifecycle services.

Constructors

BaseTelemetryService()
Creates and opens a span for name.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endSpan(String spanId, {Map<String, Object?>? attributes, Object? error}) → void
Closes a span and optionally attaches attributes and error.
log(String spanId, String message, {Map<String, Object?>? attributes}) → void
Adds one log message to the given spanId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot() List<TelemetrySpan>
Returns an immutable-style snapshot of all known spans.
startSpan(String name, {String? parentSpanId, Map<String, Object?>? attributes}) TelemetrySpan
Starts a new span.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited