InMemoryAdkMetricsRecorder class

Metrics recorder that stores samples in memory for tests and adapters.

Implemented types

Constructors

InMemoryAdkMetricsRecorder()
Creates an empty in-memory recorder.

Properties

hashCode int
The hash code for this object.
no setterinherited
records List<AdkMetricRecord>
Recorded samples in insertion order.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Removes all recorded samples.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
record(AdkMetricRecord metric) → void
Records one metric sample.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited