LiveConnectConfig class

Realtime connection configuration for live model sessions.

Constructors

LiveConnectConfig({List<String>? responseModalities, Object? speechConfig, Object? outputAudioTranscription, Object? inputAudioTranscription, Object? systemInstruction, List<ToolDeclaration>? tools, HttpOptions? httpOptions, Object? realtimeInputConfig, bool? enableAffectiveDialog, Object? proactivity, Object? sessionResumption, Object? historyConfig, Object? contextWindowCompression, bool? explicitVadSignal})
Creates live connection settings.

Properties

contextWindowCompression Object?
Provider context window compression configuration.
getter/setter pair
enableAffectiveDialog bool?
Whether affective dialog behavior is enabled.
getter/setter pair
explicitVadSignal bool?
Whether explicit Voice Activity Detection (VAD) signals should be returned.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
historyConfig Object?
Provider live history exchange configuration.
getter/setter pair
httpOptions HttpOptions?
HTTP options for the live session.
getter/setter pair
inputAudioTranscription Object?
Provider input transcription configuration.
getter/setter pair
outputAudioTranscription Object?
Provider output transcription configuration.
getter/setter pair
proactivity Object?
Provider proactivity configuration.
getter/setter pair
realtimeInputConfig Object?
Provider realtime input configuration.
getter/setter pair
responseModalities List<String>?
Requested response modalities, such as text or audio.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionResumption Object?
Provider session resumption configuration.
getter/setter pair
speechConfig Object?
Provider-specific speech configuration.
getter/setter pair
systemInstruction Object?
System instruction payload for the live session.
getter/setter pair
tools List<ToolDeclaration>?
Tool declarations available during live sessions.
getter/setter pair

Methods

copyWith({List<String>? responseModalities, Object? speechConfig = _sentinel, Object? outputAudioTranscription = _sentinel, Object? inputAudioTranscription = _sentinel, Object? systemInstruction = _sentinel, Object? tools = _sentinel, Object? httpOptions = _sentinel, Object? realtimeInputConfig = _sentinel, Object? enableAffectiveDialog = _sentinel, Object? proactivity = _sentinel, Object? sessionResumption = _sentinel, Object? historyConfig = _sentinel, Object? contextWindowCompression = _sentinel, Object? explicitVadSignal = _sentinel}) LiveConnectConfig
Returns a copy of this live configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited