StorageMetadataV1 class

Key-value metadata row model for schema v1.

Constructors

StorageMetadataV1({required String key, required String value})
Creates a storage metadata entry.
StorageMetadataV1.fromJson(Map<String, Object?> json)
Creates metadata entry from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
Metadata key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Metadata value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Serializes metadata entry to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited