StreamableHTTPConnectionParams class

Connection options for an MCP server that supports Streamable HTTP.

Constructors

StreamableHTTPConnectionParams({required String url, Map<String, String>? headers})
Creates connection options for a Streamable HTTP endpoint.

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Additional HTTP headers sent with every request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The MCP server endpoint URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited