FlutterAdkPlatform class abstract

Defines the platform interface contract for the flutter_adk plugin.

Inheritance
  • Object
  • PlatformInterface
  • FlutterAdkPlatform
Implementers

Constructors

FlutterAdkPlatform()
Creates a platform interface protected by a verification token.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
The platform version reported by this implementation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterAdkPlatform
The default instance of FlutterAdkPlatform to use.
getter/setter pair