AdkAgentMetadata class
Rich metadata, configuration, and state descriptor for an ADK agent in the management registry.
- Annotations
Constructors
-
AdkAgentMetadata({required String id, required String name, required BaseAgent agent, String description = '', String model = 'gemini-3.7-flash', String instruction = '', AdkAgentStatus status = .idle, bool isEnabled = true, int toolsCount = 0, int subAgentsCount = 0, AdkAgentMetrics metrics = const AdkAgentMetrics(), List<
String> tags = const <String>[]}) -
Creates an AdkAgentMetadata.
const
Properties
- agent → BaseAgent
-
The underlying ADK runtime agent instance.
final
- description → String
-
Description of the agent's role and capabilities.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique agent identifier.
final
- instruction → String
-
System instructions / prompt.
final
- isEnabled → bool
-
Whether this agent is enabled for execution and delegation.
final
- metrics → AdkAgentMetrics
-
Telemetry and invocation metrics.
final
- model → String
-
Primary LLM model configured for this agent.
final
- name → String
-
Human-readable display name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AdkAgentStatus
-
Current lifecycle status.
final
- subAgentsCount → int
-
Number of sub-agents orchestrated by this agent.
final
-
Categorical tags (e.g.
coding,research,customer_support).final - toolsCount → int
-
Number of tools registered to this agent.
final
Methods
-
copyWith(
{String? id, String? name, BaseAgent? agent, String? description, String? model, String? instruction, AdkAgentStatus? status, bool? isEnabled, int? toolsCount, int? subAgentsCount, AdkAgentMetrics? metrics, List< String> ? tags}) → AdkAgentMetadata - Copies this AdkAgentMetadata with updated properties.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited