AdkCustomStorage class
Adapter allowing developers to construct an AdkKeyValueStorage from simple callbacks without subclassing.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String key) → FutureOr< void> -
Deletes the entry for
key.override -
getKeys(
{String prefix = ''}) → FutureOr< List< String> > -
Returns all keys matching an optional
prefix.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String key) → FutureOr< String?> -
Reads a string value for
key, or returnsnullif not found.override -
toString(
) → String -
A string representation of this object.
inherited
-
write(
String key, String value) → FutureOr< void> -
Writes a string
valueforkey.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited