BaseArtifactService class abstract
Base contract for artifact persistence services.
Constructors
- BaseArtifactService()
- Creates an artifact persistence service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteArtifact(
{required String appName, required String userId, required String filename, String? sessionId}) → Future< void> - Deletes all versions of one artifact.
-
getArtifactVersion(
{required String appName, required String userId, required String filename, String? sessionId, int? version}) → Future< ArtifactVersion?> - Returns metadata for one artifact version.
-
listArtifactKeys(
{required String appName, required String userId, String? sessionId}) → Future< List< String> > - Lists artifact keys available in the scoped namespace.
-
listArtifactVersions(
{required String appName, required String userId, required String filename, String? sessionId}) → Future< List< ArtifactVersion> > - Lists full version metadata for one artifact key.
-
listVersions(
{required String appName, required String userId, required String filename, String? sessionId}) → Future< List< int> > - Lists numeric versions for one artifact key.
-
loadArtifact(
{required String appName, required String userId, required String filename, String? sessionId, int? version}) → Future< Part?> -
Loads an artifact by name and optional
version. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveArtifact(
{required String appName, required String userId, required String filename, required Part artifact, String? sessionId, Map< String, Object?> ? customMetadata}) → Future<int> -
Saves
artifactand returns the assigned version number. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited