BaseMemoryService class abstract
Base contract for memory ingestion and search implementations.
Constructors
- BaseMemoryService()
- Creates a memory service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addEventsToMemory(
{required String appName, required String userId, required List< Event> events, String? sessionId, Map<String, Object?> ? customMetadata}) → Future<void> -
Adds scoped
eventsto memory storage. -
addMemory(
{required String appName, required String userId, required List< MemoryEntry> memories, Map<String, Object?> ? customMetadata}) → Future<void> -
Adds pre-built
memoriesdirectly into storage. -
addSessionToMemory(
Session session) → Future< void> -
Adds all events from
sessionto memory storage. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
searchMemory(
{required String appName, required String userId, required String query}) → Future< SearchMemoryResponse> -
Searches memory using
queryfor one app/user scope. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited