InMemorySessionService class
Session service backed by process-local maps.
- Inheritance
-
- Object
- BaseSessionService
- InMemorySessionService
Constructors
- InMemorySessionService()
- Creates an in-memory session service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendEvent(
{required Session session, required Event event}) → Future< Event> -
Appends
eventtosessionand updates persisted session state.override -
createSession(
{required String appName, required String userId, Map< String, Object?> ? state, String? sessionId}) → Future<Session> -
Creates and returns a new session.
override
-
deleteSession(
{required String appName, required String userId, required String sessionId}) → Future< void> -
Deletes one session identified by app, user, and session IDs.
override
-
eventForPersistence(
Event event) → Event -
Returns the persistable form of
event.inherited -
getSession(
{required String appName, required String userId, required String sessionId, GetSessionConfig? config}) → Future< Session?> -
Returns a single session when it exists, otherwise
null.override -
listSessions(
{required String appName, String? userId}) → Future< ListSessionsResponse> -
Returns sessions for
appName, optionally scoped touserId.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited