InMemorySkillData class
Complete in-memory payload for one skill source entry.
Constructors
-
InMemorySkillData({required Frontmatter frontmatter, required String instructions, Map<
String, List< ? resources})int> > - Creates in-memory skill data.
- InMemorySkillData.fromSkill(Skill skill)
-
Builds skill data from a complete Skill.
factory
Properties
- frontmatter → Frontmatter
-
Frontmatter for this skill.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instructions → String
-
Instruction body for this skill.
final
-
resources
→ Map<
String, List< int> > -
Resource bytes keyed by path relative to skill root.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited