InlineData class
Inline binary payload attached to a Part.
Constructors
-
InlineData({required String mimeType, required List<
int> data, String? displayName}) - Creates inline binary data.
Properties
-
data
↔ List<
int> -
Raw binary bytes.
getter/setter pair
- displayName ↔ String?
-
Optional display label.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType ↔ String
-
MIME type for data.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? mimeType, List< int> ? data, Object? displayName = _sentinel}) → InlineData - Returns a copy of this inline payload with optional overrides.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited