LiveRequest class
A single queued live request payload.
Constructors
- LiveRequest({Content? content, Object? blob, LiveActivityStart? activityStart, LiveActivityEnd? activityEnd, bool close = false})
- Creates a live request envelope.
Properties
- activityEnd ↔ LiveActivityEnd?
-
Activity-end marker payload.
getter/setter pair
- activityStart ↔ LiveActivityStart?
-
Activity-start marker payload.
getter/setter pair
- blob ↔ Object?
-
Opaque realtime blob payload.
getter/setter pair
- close ↔ bool
-
Whether this request closes the queue.
getter/setter pair
- content ↔ Content?
-
Structured content payload.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited