MemoryEntry class
One memory item with content and optional metadata.
Constructors
Properties
-
Optional source author.
getter/setter pair
- content ↔ Content
-
Content payload stored in memory.
getter/setter pair
-
customMetadata
↔ Map<
String, Object?> -
Provider-specific metadata attached to this memory.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Optional memory identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ String?
-
Optional source timestamp string.
getter/setter pair
Methods
-
copyWith(
{Content? content, Map< String, Object?> ? customMetadata, Object? id = _sentinel, Object? author = _sentinel, Object? timestamp = _sentinel}) → MemoryEntry - Returns a copied memory entry with optional overrides.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited