ResumabilityConfig class
Resumability settings for an app.
Constructors
- ResumabilityConfig({bool isResumable = false})
- Creates resumability settings.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isResumable ↔ bool
-
Whether invocation resumption is enabled.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited