StdioConnectionParams class
Process launch options for an MCP stdio server.
Constructors
Properties
-
arguments
→ List<
String> -
Arguments passed to command.
final
- command → String
-
The executable to start.
final
- connectionId → String?
-
Optional stable identifier used in callbacks and logs.
final
-
environment
→ Map<
String, String> ? -
Extra environment variables for the process.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeParentEnvironment → bool
-
Whether to inherit the parent process environment.
final
- resolvedConnectionId → String
-
A stable connection id derived from connectionId, command, and args.
no setter
- runInShell → bool
-
Whether to spawn the process through a shell.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workingDirectory → String?
-
The working directory for the process, when provided.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited